Simulation with observer based state feedback of the string with mass model
---------------------------------------------------------------------------

.. autoapimodule:: pyinduct.examples.string_with_mass
    :members:
    :no-imported-members:
    :undoc-members:
    :show-inheritance:

